@@ -9,6 +9,7 @@ use crate::{DocId, UpdateId};
 pub struct Options {
     /// The server address in the format of ip_addr:port (ex: http://0.0.0.0:7700)
     #[structopt(
+        global = true,
         short,
         long,
         default_value = "http://localhost:7700",
@@ -17,11 +18,21 @@ pub struct Options {
     pub addr: String,
 
     /// The name of the index
-    #[structopt(short, long, default_value = "mieli")]
+    #[structopt(global = true, short, long, default_value = "mieli")]
     pub index: String,
 
+    /// Your secret API key https://docs.meilisearch.com/reference/api/keys.html#get-keys
+    #[structopt(
+        global = true,
+        short,
+        long,
+        default_value = "",
+        env = "MEILI_MASTER_KEY"
+    )]
+    pub key: String,
+
     /// Interval between each status check (in milliseconds)
-    #[structopt(long, default_value = "200")]
+    #[structopt(global = true, long, default_value = "200")]
     pub interval: usize,
 
     #[structopt(subcommand)]
@@ -42,7 +53,7 @@ pub enum Command {
         #[structopt(short, default_value = "application/json")]
         content_type: String,
         /// The command will exit immediatly after sending the documents
-        #[structopt(short, long)]
+        #[structopt(long)]
         r#async: bool,
         /// The file you want to send
         file: Option<PathBuf>,
@@ -54,7 +65,7 @@ pub enum Command {
         #[structopt(short, default_value = "application/json")]
         content_type: String,
         /// The command will exit immediatly after sending the documents
-        #[structopt(short, long)]
+        #[structopt(long)]
         r#async: bool,
         /// The file you want to send
         file: Option<PathBuf>,
@@ -64,19 +75,25 @@ pub enum Command {
         /// The list of document ids you want to delete
         document_ids: Vec<DocId>,
         /// The command will exit immediatly after sending the documents ids
-        #[structopt(short, long)]
+        #[structopt(long)]
         r#async: bool,
     },
     /// Create a dump or get the status of a dump
     Dump {
         /// The command will exit immediatly after asking for a dump
-        #[structopt(short, long)]
+        #[structopt(long)]
         r#async: bool,
         /// The dump you want info from
         dump_id: Option<String>,
     },
     /// Return the status of an update
-    Status { update_id: UpdateId },
+    Status {
+        /// The update id
+        update_id: UpdateId,
+        /// If the flag is set, the command will wait until the update finishes
+        #[structopt(short, long)]
+        watch: bool,
+    },
     /// Do an healthcheck
     Health,
     /// Return the version of the running meilisearch instance
@@ -85,15 +102,13 @@ pub enum Command {
     Stats,
     /// Do a search. You must pipe your parameter in the command as a json
     Search {
-        #[structopt(short)]
-        message: Option<String>,
-        #[structopt(short)]
+        #[structopt(long)]
         all: bool,
     },
     /// Update the settings. You must pipe your parameter in the command as a json.
     Settings {
         /// The command will exit immediatly after asking for a dump
-        #[structopt(short, long)]
+        #[structopt(long)]
         r#async: bool,
     },
 }
